@@ -4,22 +4,12 @@ class Api(object):
     """TBD
     """
 
-    def set_config(self, content):
+    def set_state(self, content):
         """TBD
         """
         raise NotImplementedError
 
-    def set_port_link(self, content):
-        """TBD
-        """
-        raise NotImplementedError
-
-    def set_port_capture(self, content):
-        """TBD
-        """
-        raise NotImplementedError
-
-    def set_flow_transmit(self, content):
+    def get_state_results(self, content):
         """TBD
         """
         raise NotImplementedError
@@ -29,6 +19,11 @@ class Api(object):
         """
         raise NotImplementedError
 
+    def get_config(self, content):
+        """TBD
+        """
+        raise NotImplementedError
+
     def get_port_results(self, content):
         """TBD
         """
